Initial import

This commit is contained in:
2022-08-30 15:46:53 -04:00
commit e712bb5dc2
274 changed files with 27716 additions and 0 deletions

View File

@@ -0,0 +1,77 @@
From: Mike Hommey <glandium@debian.org>
Date: Sat, 21 Jun 2008 02:48:46 +0200
Subject: Allow .js preference files to set locked prefs with lockPref()
---
modules/libpref/parser/src/lib.rs | 23 ++++++++++++-----------
1 file changed, 12 insertions(+), 11 deletions(-)
diff --git a/xpcom/glue/standalone/nsXPCOMGlue.cpp b/xpcom/glue/standalone/nsXPCOMGlue.cpp
index cf8e265..d1c5a85 100644
--- a/xpcom/glue/standalone/nsXPCOMGlue.cpp
+++ b/xpcom/glue/standalone/nsXPCOMGlue.cpp
@@ -132,6 +132,9 @@ static bool ReadDependentCB(pathstr_t aDependentLib,
ReadAheadLib(aDependentLib);
}
#endif
+ char lib[MAXPATHLEN];
+ if (realpath(aDependentLib, lib))
+ aDependentLib = lib;
LibHandleType libHandle = GetLibHandle(aDependentLib);
if (libHandle) {
AppendDependentLib(libHandle);

View File

@@ -0,0 +1,24 @@
From: Mike Hommey <glandium@debian.org>
Date: Sat, 22 Nov 2008 09:35:23 +0100
Subject: Properly launch applications set in $HOME/.mailcap
https://bugzilla.mozilla.org/show_bug.cgi?id=444440
---
uriloader/exthandler/unix/nsMIMEInfoUnix.cpp | 4 ++++
1 file changed, 4 insertions(+)
diff --git a/uriloader/exthandler/unix/nsMIMEInfoUnix.cpp b/uriloader/exthandler/unix/nsMIMEInfoUnix.cpp
index 7cbefcc..c4bafef 100644
--- a/uriloader/exthandler/unix/nsMIMEInfoUnix.cpp
+++ b/uriloader/exthandler/unix/nsMIMEInfoUnix.cpp
@@ -53,6 +53,10 @@ nsresult nsMIMEInfoUnix::LaunchDefaultWithFile(nsIFile* aFile) {
if (mDefaultApplication) return nsMIMEInfoImpl::LaunchDefaultWithFile(aFile);
nsAutoCString nativePath;
+/* the name of the function has changed
+ * the old was the following:
+ nsCAutoString nativePath;
+ */
aFile->GetNativePath(nativePath);
nsCOMPtr<nsIGIOService> giovfs = do_GetService(NS_GIOSERVICE_CONTRACTID);

View File

@@ -0,0 +1,22 @@
From: Carsten Schoenert <c.schoenert@t-online.de>
Date: Sat, 9 Mar 2013 20:30:54 +0100
Subject: fix function nsMsgComposeAndSend to respect ReploToSend
https://bugzilla.mozilla.org/show_bug.cgi?id=522450
Closes: #565903
---
comm/mailnews/compose/src/nsMsgSend.cpp | 1 +
1 file changed, 1 insertion(+)
diff --git a/comm/mailnews/compose/src/nsMsgSend.cpp b/comm/mailnews/compose/src/nsMsgSend.cpp
index a1e1b40..b0525a3 100644
--- a/comm/mailnews/compose/src/nsMsgSend.cpp
+++ b/comm/mailnews/compose/src/nsMsgSend.cpp
@@ -2326,6 +2326,7 @@ nsresult nsMsgComposeAndSend::InitCompositionFields(
(aType == nsIMsgCompType::Reply ||
aType == nsIMsgCompType::ReplyAll ||
aType == nsIMsgCompType::ReplyToGroup ||
+ aType == nsIMsgCompType::ReplyToList ||
aType == nsIMsgCompType::ReplyToSender ||
aType == nsIMsgCompType::ReplyToSenderAndGroup ||
aType == nsIMsgCompType::ReplyWithTemplate)) {
diff --git a/modules/libpref/parser/src/lib.rs b/modules/libpref/parser/src/lib.rs
index a8c5b6b..aceacf3 100644
--- a/modules/libpref/parser/src/lib.rs
+++ b/modules/libpref/parser/src/lib.rs
@@ -10,7 +10,7 @@
//!
//! <pref-file> = <pref>*
//! <pref> = <pref-spec> "(" <pref-name> "," <pref-value> <pref-attrs> ")" ";"
//! <pref-spec> = "user_pref" | "pref" | "sticky_pref" // in default pref files
//! <pref-spec> = "user_pref" // in user pref files
//! <pref-name> = <string-literal>
//! <pref-value> = <string-literal> | "true" | "false" | <int-value>
@@ -169,6 +169,7 @@ enum Token {
// Keywords
Pref, // pref
StickyPref, // sticky_pref
+ LockPref, // lockPref
UserPref, // user_pref
True, // true
False, // false
@@ -291,7 +292,7 @@ struct KeywordInfo {
token: Token,
}
-const KEYWORD_INFOS: [KeywordInfo; 7] = [
+const KEYWORD_INFOS: [KeywordInfo; 8] = [
// These are ordered by frequency.
KeywordInfo {
string: b"pref",
@@ -321,6 +322,10 @@ const KEYWORD_INFOS: [KeywordInfo; 7] = [
string: b"sticky_pref",
token: Token::StickyPref,
},
+ KeywordInfo {
+ string: b"lock_pref",
+ token: Token::LockPref,
+ },
];
struct Parser<'t> {
@@ -373,14 +378,11 @@ impl<'t> Parser<'t> {
// this will be either the first token of a new pref, or EOF.
loop {
// <pref-spec>
- let (pref_value_kind, mut is_sticky) = match token {
- Token::Pref if self.kind == PrefValueKind::Default => {
- (PrefValueKind::Default, false)
- }
- Token::StickyPref if self.kind == PrefValueKind::Default => {
- (PrefValueKind::Default, true)
- }
- Token::UserPref => (PrefValueKind::User, false),
+ let (pref_value_kind, mut is_sticky, mut is_locked) = match token {
+ Token::Pref => (PrefValueKind::Default, false, false),
+ Token::StickyPref => (PrefValueKind::Default, true, false),
+ Token::LockPref => (PrefValueKind::Default, false, true),
+ Token::UserPref => (PrefValueKind::User, false, false),
Token::SingleChar(EOF) => return !self.has_errors,
_ => {
token = self.error_and_recover(
@@ -490,7 +492,6 @@ impl<'t> Parser<'t> {
};
// ("," <pref-attr>)* // default pref files only
- let mut is_locked = false;
let mut has_attrs = false;
if self.kind == PrefValueKind::Default {
let ok = loop {

View File

@@ -0,0 +1,22 @@
From: Christoph Goehre <chris@sigxcpu.org>
Date: Mon, 16 Sep 2013 20:40:57 +0200
Subject: Load-dependent-libraries-with-their-real-path-to-avo
---
xpcom/glue/standalone/nsXPCOMGlue.cpp | 3 +++
1 file changed, 3 insertions(+)
@@ -10,7 +10,7 @@
//! <pref-file> = <pref>*
//! <pref> = <pref-spec> "(" <pref-name> "," <pref-value> <pref-attrs> ")" ";"
-//! <pref-spec> = "user_pref" | "pref" | "sticky_pref" // in default pref files
+//! <pref-spec> = "user_pref" | "pref" | "sticky_pref | lockPref" // in default pref files
//! <pref-spec> = "user_pref" // in user pref files
//! <pref-name> = <string-literal>